// Package common provides primitives to interact with the openapi HTTP API.
//
// Code generated by github.com/deepmap/oapi-codegen version v1.9.1 DO NOT EDIT.
package common

import (
	"bytes"
	"compress/gzip"
	"encoding/base64"
	"fmt"
	"net/url"
	"path"
	"strings"

	"github.com/getkin/kin-openapi/openapi3"
)

// AccumulatedUsage defines model for AccumulatedUsage.
type AccumulatedUsage struct {
	// Unsigned integer identifying a volume in units of bytes.
	DownlinkVolume *Volume `json:"downlinkVolume,omitempty"`

	// Unsigned integer identifying a period of time in units of seconds.
	Duration *DurationSec `json:"duration,omitempty"`

	// Unsigned integer identifying a volume in units of bytes.
	TotalVolume *Volume `json:"totalVolume,omitempty"`

	// Unsigned integer identifying a volume in units of bytes.
	UplinkVolume *Volume `json:"uplinkVolume,omitempty"`
}

// Acknowledgement defines model for Acknowledgement.
type Acknowledgement struct {
	// A human-readable explanation specific to this successful acknowledgement
	Details string `json:"details"`
}

// integer indicating a bandwidth in bits per second.
type Bandwidth int

// string identifying a BDT Reference ID as defined in subclause 5.3.3 of 3GPP TS 29.154.
type BdtReferenceId string

// This data type is defined in the same way as the BdtReferenceId data type, but with the nullable property set to true.
type BdtReferenceIdRm string

// string with format "binary" as defined in OpenAPI Specification.
type Binary string

// String with format "byte" as defined in OpenAPI Specification, i.e, base64-encoded characters.
type Bytes string

// ConfigResult defines model for ConfigResult.
type ConfigResult interface{}

// string with format "date-time" as defined in OpenAPI.
type DateTime string

// string with format "date-time" as defined in OpenAPI with "nullable=true" property.
type DateTimeRm string

// string with format "date-time" as defined in OpenAPI with "readOnly=true" property.
type DateTimeRo string

// integer between and including 1 and 7 denoting a weekday. 1 shall indicate Monday, and the subsequent weekdays shall be indicated with the next higher numbers. 7 shall indicate Sunday.
type DayOfWeek int

// Unsigned integer identifying a period of time in units of minutes.
type DurationMin int32

// Unsigned integer identifying a period of time in units of seconds.
type DurationSec int

// Unsigned integer identifying a period of time in units of seconds with "nullable=true" property.
type DurationSecRm int

// Unsigned integer identifying a period of time in units of seconds with "readOnly=true" property.
type DurationSecRo int

// Possible values are - SESSION_TERMINATION: Indicates that Rx session is terminated. - LOSS_OF_BEARER : Indicates a loss of a bearer. - RECOVERY_OF_BEARER: Indicates a recovery of a bearer. - RELEASE_OF_BEARER: Indicates a release of a bearer. - USAGE_REPORT: Indicates the usage report event.  - FAILED_RESOURCES_ALLOCATION: Indicates the resource allocation is failed.
type Event interface{}

// EventReport defines model for EventReport.
type EventReport struct {
	AccumulatedUsage *AccumulatedUsage `json:"accumulatedUsage,omitempty"`

	// Possible values are - SESSION_TERMINATION: Indicates that Rx session is terminated. - LOSS_OF_BEARER : Indicates a loss of a bearer. - RECOVERY_OF_BEARER: Indicates a recovery of a bearer. - RELEASE_OF_BEARER: Indicates a release of a bearer. - USAGE_REPORT: Indicates the usage report event.  - FAILED_RESOURCES_ALLOCATION: Indicates the resource allocation is failed.
	Event Event `json:"event"`

	// Identifies the IP flows that were sent during event subscription
	FlowIds *[]int `json:"flowIds,omitempty"`
}

// string containing a local identifier followed by "@" and a domain identifier. Both the local identifier and the domain identifier shall be encoded as strings that do not contain any "@" characters. See Clauses 4.6.2 and 4.6.3 of 3GPP TS 23.682 for more information.
type ExternalGroupId string

// string containing a local identifier followed by "@" and a domain identifier. Both the local identifier and the domain identifier shall be encoded as strings that do not contain any "@" characters. See Clause 4.6.2 of 3GPP TS 23.682 for more information.
type ExternalId string

// FlowInfo defines model for FlowInfo.
type FlowInfo struct {
	// Indicates the packet filters of the IP flow. Refer to subclause 5.3.8 of 3GPP TS 29.214 for encoding. It shall contain UL and/or DL IP flow description.
	FlowDescriptions *[]string `json:"flowDescriptions,omitempty"`

	// Indicates the IP flow.
	FlowId int `json:"flowId"`
}

// InvalidParam defines model for InvalidParam.
type InvalidParam struct {
	// Attribute's name encoded as a JSON Pointer, or header's name.
	Param string `json:"param"`

	// A human-readable reason, e.g. "must be a positive integer".
	Reason *string `json:"reason,omitempty"`
}

// string identifying a Ipv4 address formatted in the "dotted decimal" notation as defined in IETF RFC 1166.
type Ipv4Addr string

// string identifying a Ipv4 address formatted in the "dotted decimal" notation as defined in IETF RFC 1166, with "readOnly=true" property.
type Ipv4AddrRo string

// string identifying a Ipv6 address formatted according to clause 4 in IETF RFC 5952. The mixed Ipv4 Ipv6 notation according to clause 5 of IETF RFC 5952 shall not be used.
type Ipv6Addr string

// string identifying a Ipv6 address formatted according to clause 4 in IETF RFC 5952, with "readOnly=true" property. The mixed Ipv4 Ipv6 notation according to clause 5 of IETF RFC 5952 shall not be used.
type Ipv6AddrRo string

// string formatted according to IETF RFC 3986 identifying a referenced resource.
type Link string

// String encoding a Mobile Country Code part of the PLMN, comprising 3 digits, as defined in 3GPP TS 38.413.
type Mcc string

// String encoding a Mobile Network Code part of the PLMN, comprising 2 or 3 digits, as defined in 3GPP TS 38.413.
type Mnc string

// string formatted according to subclause 3.3 of 3GPP TS 23.003 that describes an MSISDN.
type Msisdn string

// NotificationData defines model for NotificationData.
type NotificationData struct {
	// Contains the reported event and applicable information
	EventReports []EventReport `json:"eventReports"`

	// string formatted according to IETF RFC 3986 identifying a referenced resource.
	Transaction Link `json:"transaction"`
}

// PlmnId defines model for PlmnId.
type PlmnId struct {
	// String encoding a Mobile Country Code part of the PLMN, comprising 3 digits, as defined in 3GPP TS 38.413.
	Mcc Mcc `json:"mcc"`

	// String encoding a Mobile Network Code part of the PLMN, comprising 2 or 3 digits, as defined in 3GPP TS 38.413.
	Mnc Mnc `json:"mnc"`
}

// Unsigned integer with valid values between 0 and 65535.
type Port int

// Unsigned integer with valid values between 0 and 65535, with "readOnly=true" property.
type PortRo int

// ProblemDetails defines model for ProblemDetails.
type ProblemDetails struct {
	// A machine-readable application error cause specific to this occurrence of the problem. This IE should be present and provide application-related error information, if available.
	Cause *string `json:"cause,omitempty"`

	// A human-readable explanation specific to this occurrence of the problem.
	Detail *string `json:"detail,omitempty"`

	// string providing an URI formatted according to IETF RFC 3986.
	Instance *Uri `json:"instance,omitempty"`

	// Description of invalid parameters, for a request rejected due to invalid parameters.
	InvalidParams *[]InvalidParam `json:"invalidParams,omitempty"`

	// The HTTP status code for this occurrence of the problem.
	Status *int `json:"status,omitempty"`

	// A short, human-readable summary of the problem type. It should not change from occurrence to occurrence of the problem.
	Title *string `json:"title,omitempty"`

	// string providing an URI formatted according to IETF RFC 3986.
	Type *Uri `json:"type,omitempty"`
}

// string chosen by the SCEF to serve as identifier in a resource URI.
type ResourceId string

// Possible values are - ROAMING_NOT_ALLOWED: Identifies the configuration parameters are not allowed by roaming agreement. - OTHER_REASON: Identifies the configuration parameters are not configured due to other reason.
type ResultReason interface{}

// string that identifies an SCS/AS.
type ScsAsId string

// SponsorInformation defines model for SponsorInformation.
type SponsorInformation struct {
	// It indicates Application Service Provider ID.
	AspId string `json:"aspId"`

	// It indicates Sponsor ID.
	SponsorId string `json:"sponsorId"`
}

// TestNotification defines model for TestNotification.
type TestNotification struct {
	// string formatted according to IETF RFC 3986 identifying a referenced resource.
	Subscription Link `json:"subscription"`
}

// String with format partial-time or full-time as defined in subclause 5.6 of IETF RFC 3339. Examples, 20:15:00, 20:15:00-08:00 (for 8 hours behind UTC).
type TimeOfDay string

// TimeWindow defines model for TimeWindow.
type TimeWindow struct {
	// string with format "date-time" as defined in OpenAPI.
	StartTime DateTime `json:"startTime"`

	// string with format "date-time" as defined in OpenAPI.
	StopTime DateTime `json:"stopTime"`
}

// string providing an URI formatted according to IETF RFC 3986.
type Uri string

// UsageThreshold defines model for UsageThreshold.
type UsageThreshold struct {
	// Unsigned integer identifying a volume in units of bytes.
	DownlinkVolume *Volume `json:"downlinkVolume,omitempty"`

	// Unsigned integer identifying a period of time in units of seconds.
	Duration *DurationSec `json:"duration,omitempty"`

	// Unsigned integer identifying a volume in units of bytes.
	TotalVolume *Volume `json:"totalVolume,omitempty"`

	// Unsigned integer identifying a volume in units of bytes.
	UplinkVolume *Volume `json:"uplinkVolume,omitempty"`
}

// UsageThresholdRm defines model for UsageThresholdRm.
type UsageThresholdRm struct {
	// Unsigned integer identifying a volume in units of bytes with "nullable=true" property.
	DownlinkVolume *VolumeRm `json:"downlinkVolume"`

	// Unsigned integer identifying a period of time in units of seconds with "nullable=true" property.
	Duration *DurationSecRm `json:"duration"`

	// Unsigned integer identifying a volume in units of bytes with "nullable=true" property.
	TotalVolume *VolumeRm `json:"totalVolume"`

	// Unsigned integer identifying a volume in units of bytes with "nullable=true" property.
	UplinkVolume *VolumeRm `json:"uplinkVolume"`
}

// Unsigned integer identifying a volume in units of bytes.
type Volume int64

// Unsigned integer identifying a volume in units of bytes with "nullable=true" property.
type VolumeRm int64

// WebsockNotifConfig defines model for WebsockNotifConfig.
type WebsockNotifConfig struct {
	// Set by the SCS/AS to indicate that the Websocket delivery is requested.
	RequestWebsocketUri *bool `json:"requestWebsocketUri,omitempty"`

	// string formatted according to IETF RFC 3986 identifying a referenced resource.
	WebsocketUri *Link `json:"websocketUri,omitempty"`
}

// Base64 encoded, gzipped, json marshaled Swagger object
var swaggerSpec = []string{

	"H4sIAAAAAAAC/+Ra3W7juJJ+lYJ2gT0Hqyj+STLdBhZYt+308SKJDcuZxmLSCGipbPFEIjUkFcczyLvk",
	"dl8jT7YgKdmyrMTOpOfkYm66Y4lkfSyyqr6q0u9OwJOUM2RKOp3fHYEy5Uyi+XHSaOj/As4UMqX/JGka",
	"04AoytlxKvgsxuQ//yk50+9kEGFC9F//LnDudJx/O96sfWzfyuOxndVHRWgsncfHR9cJUQaCpnpVp+N8",
	"ISEI/DVDqZxH1zlpND8AxDUjmYq4oL9haFG0PwDFORczGobILISTD4BwxRWc84zlWjj7IAjdIMBUkVmM",
	"FsfnD8DR42we08DeyuZH3MoLZAsVwQR/zajIL2az9QFAxgIDzkKqf8I5oXEB5iOsZExWMSchTDmHCyIW",
	"9oo0P8JaridDC4OzhUVx+iHOS2ZpyoXCEC4xpASmq9RqpfURhqM1cknYylxclEpqKKcfElyGTKFgJAYf",
	"xT0KGAjBhYXzEVdXo6ABwjUj94TGhX8LcU6y2KDYHv8VGQoaFLAf3RyJCdfdIMiSLCYKw2tJFqifpYKn",
	"KBS1AT3kSxZTdvczj7ME98HPR2k8mSAWwesz+vk4HwM9TXFF4rfKytK3I9Sy9A3vOHz2T7QeuhvcMb6M",
	"MVxgkp9oRRn5sewouQtRlhB2JJCE+kQAH9KYMLMzkCkGdE4DUBxURCXILAhQynkWA6mIXKOSSlDtEB5d",
	"RxS+u/PLGsH3GvhfCAuXNFTRLj7KFC5QAGWhuZ9sAQRmxXigDGZUSUhRgDRu2nNcJ6GMJlnidBprYfk6",
	"RlqoJjhHgSzAYbgr0m4AaIhM0fnKivzSn8J6Fgz7QCSEOKcMQw1CZrMgJpnE56dTr+21gc+h/XU8fn6a",
	"+s9Prc9e8/TE29VRFcwk2YUz1YoPiSKgJwPdkqsiBEkShCVZaUj69/aSm6kuzDIFS6oiM4xlsbFByG/K",
	"CiQqc9IiQ421GOB09JM67JQRsXpRgUbSnIuEKLhxZmbwjVNR3ChF1h0Pwc+vmrl49ZpaKay5wH6tsJXC",
	"l0Q9P23JcoF6WjVE4tnJEbKAhxhCEBFBAoVC1mLR7IguJihzx8UZjuZO55fft648Plj/Owyl8/3R3X6Z",
	"SCpDpl98dyvGWp63s98BCSLA2BhdYRUogTAophU3l6LQ11Cf9fVAb4MqTOQ+NzNYC9cbTSgb2lnNtRqI",
	"EGRlXuZb2IOxQGNv56UPtIhLY396dTz0+1fAsmSGAkgcc72fUB/lW5FfGjh7UQtzahMkcr+Pn5THVj3a",
	"1kJ1bq1PFE6p9ewHWEhIFB4pmrx4c2uvYiGkznX8MTF2/M3a/v9Lm/+Ns/YTB/mGNSz+o2A9P+W4dKga",
	"sXhVh6t49wqu1Wj+DfHu5VAzQ7VEZECYFh/EWajRNs3vnyBExvMwtES8C8nKgybIiMTx2hzhkrOQrFwz",
	"xbjobCY1HWSqmCTzKTNczwpLvhkfFER0EaHITUN68FNVip9pKSbgkQcb8H4qBb9mXfArWMslZbsauGaS",
	"LqzW86i7FQNTFJSHxqfQROOGjOngy+eQUJYpNM7SnqiV2m7tjcZlGvUDAVkyIL23yK8zoXcjOMSayghf",
	"sKwXEPM/EfFrdlZG/ILNlRAP7os0g63yOIlMz/7F8Qe+Pxxd3U4Hk8vhVXc6HF05rnMx8v3b0fntl0F3",
	"Mpg4rjMZ9EY/Dyb/W3l4Mej6g61n13736+B2MhiPJlPHdc67w4tB/3Yy8EfXk97Av+1eXIx6Vsz3XfdQ",
	"y71yd5UKfk9DlNplLYkIj3S8IIrOaEzVKvdmmcoEmkjMJOVMWuaMoLeL9tgMC6MSGFeQSQz1EEs7IE/I",
	"qgQvFSj143sUelEb1KkEHRJu2G5Q+L5TNOBSUk317kmcabIgEI6gRvUdGK4ZhYqIgskDSJRGKpWgUCSU",
	"aVflwRFsHxKU5xKIuTR3isAMiUChJ+we4vYcgQG/R7HanVc55+q0GInE6qzyTdjeF0KmU0YQmHKhAPXt",
	"9ACO4JXbUl1BoOSZCLCgLLmG5qY8pE+luPYTI2Q3IyM1CexrVGQn4X10HSzs6lVCZwY9us485staSjnc",
	"ZmjDMeih+Q1YokAw1y/MjB0YoSairZcoEbRd43+FjFUIld1OHZMqSOlXwbP0lZxNGxChzHo6fS5bZHjO",
	"45gvMYTZCm6c/9ZEg4VAIOQJoaw00oMvPI/EO4sUIX1n0iagF0kEKXxHrsqQG6PPQQJhBYxStgE+IvRM",
	"Kimfn068M69lROq/qlll2zv71DJMOeFCu3Ibel9KoErM/i+hv0J971LauTYaNue7BqxtpL9RYp1dbXmM",
	"lAR3qGBOYw20yMxyY/NscUHHgkop4dNOKaHVPDH4jZooW3gwVLnyCtVcX2g9H3MB/YtCBJTAeTUmu9lz",
	"Qh5yi23tyaWsS9m382KPzi43qHiAfL06FzBk9ySm4ZgIkuweRlo8rlS3lBJ0lin8DwmMJFtXi8D/+KMr",
	"GHOTjrrABURIQhT52NrrINZp454ymh3oAnoLD26cJJNKX20CKZdU0Xss6NmN4+2tndnd1WolvT/phqE4",
	"sIqlhwMJQ4FS5qmX2vCMGyfk5neIAU1IfONoe7OxbTslGw6m589Pk/Pe81OzeXZWq6oC2isZ4L8EnAs/",
	"Im8cpvdnb1P0Wc1eSBBwYdJJxcFaOZxUMJ9+Pm15MI0QEvqAoVWLWW+z35plTrWfqCyTewXtNGdoyOZL",
	"J3X21pN6z+72n8ifuf29R31B2d2LinhhtyXJ7c+fzir6EkU5NlzzxtqDuAyCFwuchbcHApd8RmOEHs+Y",
	"Eivo6dQhJUIVMWV8cXnlgqaCgko9pQ0hXVAl3YqlbMJK+5N30mzXg2JvAXWFasnF3QGgWtrjvg+ZLfi9",
	"8ahK8bVdQ6kajXbONsyaM1tbvfSHfv+qFsUVV+ticp8oshuccJMH1LCEno3ZRVqRtzItyzb8yrbmdFAp",
	"kZWDy7mlHGRfZVQJwiQJDml+GRuphqnyfHd713WxaxwnzJKHbXUl1gpeLfUGpueWsP0jWbCDUwuwk2th",
	"5enanqqKcWGGkhRZdVE3bJhjOzs9bZ9u1ebMk33lKC39oKrOQfIPin2vAdxf26n0fXdOM9CmVkeYEhJE",
	"lOGGMpV60IBCcAFm7m4XkgdBJmwjLncuectaxw0qYTgAGfEsDrXbL4onWid5Cacs6UigyalziSULc4HO",
	"Yd2prjV929N8b1P15e3UyaRMKsKCvfWCa0Ht8A1trnE+pQRGC89HgyGcqPMU16QapPhIDQRqO9E0LEO9",
	"g90ZB/drthj9Pt8kFVGZrOuOIvxjOh2DHQCmjmabRweqtnSXFVVx7V2VERfKrZ6qzJKE2HJVaWnTa81z",
	"MnMJTc4aEbZAmAuelEEp/sbTtw8OOPm6rwQmOfd4rQAQcYlMJ/gaid8bnJuQieIedYQuZes6Ad9Uwa4n",
	"9d2pSaXZtlsAnoy6l8Orr7dXo6kpt30b9B3XGU3/MZjcTgZd/x2FWmLKcZkosrH3FEtrYHagUjgLTFc4",
	"r86XLMIsoW8B2dRPBCeJIU4LgaZP6sERlHf99tWLARvj5CpCUdr8o+v4gezKVy6AoT6lli1h4Pf8465f",
	"e7x+ypnkYljiJbuFTllbsRuWu9fdkusvPhMa22MUMOzXypa57H1r5xjrl6kwg82abo67jiFMUaoy69vd",
	"81Z19I9Qqa0FajHQBEfzPlkd9EWEJuKUxKa/qmn3PIvzHy98xgKn3lmRUcHkvAftdvuzB4MHkqQxShda",
	"jU7ztNNobP46anzqNBrwN+18P0HEM6EpSURZCNfT3t9rz1Dv4htlIV/W6FARoYr2+asfYhVtdhMmePq2",
	"OVXFr6WWFqs7AO1lXzIi64GMeTPtGg/MGmtVZIr900igjHgc/rU/c9vWhW3XVvul79fOJPmD+rET36wh",
	"O+3tOtLz6rS0WeNNjeF7M22rITxb1fT0z0729tTX+H4UhkOa6K9i3N9V/4YzyYM749ft5127tpaT4Hwo",
	"qlof4KPa8CcdOS1Nzr/ZMPFVv1svAiHG1LQ9qSxo9lahbsZ5jMRE72VF8kFxpXJB9KPiU7E+D2o4dfvr",
	"eAxTH1qfvWarBT83z7wzrwHTT5tCFqScMmWI9hUXKprxjIXQHQ+l4zqZiJ2OEymVdo6Pl8ul116kqcfF",
	"4niu0mM/xUAeExFE9B6PW59vJQqK8thKO7ZJy7wmBe4XHzLKck3E0NN7FCQ24r0b9vx/0Gq0Gq6p68BI",
	"LAijvxkbJTGMiVBMs6a/dSfDLy50p0PfhV7P77owmPpDF6Z+3/w37ep/en/3blg3jkHQRaT0ARkyHOZc",
	"0iYMzkZZPZ4knIHBOtVYHdfJ+/ZOx2l6Ta+hd8hTZCSlWtlew2s4rpMSFemzeHz8/wAAAP//Uv7ReKc0",
	"AAA=",
}

// GetSwagger returns the content of the embedded swagger specification file
// or error if failed to decode
func decodeSpec() ([]byte, error) {
	zipped, err := base64.StdEncoding.DecodeString(strings.Join(swaggerSpec, ""))
	if err != nil {
		return nil, fmt.Errorf("error base64 decoding spec: %s", err)
	}
	zr, err := gzip.NewReader(bytes.NewReader(zipped))
	if err != nil {
		return nil, fmt.Errorf("error decompressing spec: %s", err)
	}
	var buf bytes.Buffer
	_, err = buf.ReadFrom(zr)
	if err != nil {
		return nil, fmt.Errorf("error decompressing spec: %s", err)
	}

	return buf.Bytes(), nil
}

var rawSpec = decodeSpecCached()

// a naive cached of a decoded swagger spec
func decodeSpecCached() func() ([]byte, error) {
	data, err := decodeSpec()
	return func() ([]byte, error) {
		return data, err
	}
}

// Constructs a synthetic filesystem for resolving external references when loading openapi specifications.
func PathToRawSpec(pathToFile string) map[string]func() ([]byte, error) {
	var res = make(map[string]func() ([]byte, error))
	if len(pathToFile) > 0 {
		res[pathToFile] = rawSpec
	}

	return res
}

// GetSwagger returns the Swagger specification corresponding to the generated code
// in this file. The external references of Swagger specification are resolved.
// The logic of resolving external references is tightly connected to "import-mapping" feature.
// Externally referenced files must be embedded in the corresponding golang packages.
// Urls can be supported but this task was out of the scope.
func GetSwagger() (swagger *openapi3.T, err error) {
	var resolvePath = PathToRawSpec("")

	loader := openapi3.NewLoader()
	loader.IsExternalRefsAllowed = true
	loader.ReadFromURIFunc = func(loader *openapi3.Loader, url *url.URL) ([]byte, error) {
		var pathToFile = url.String()
		pathToFile = path.Clean(pathToFile)
		getSpec, ok := resolvePath[pathToFile]
		if !ok {
			err1 := fmt.Errorf("path not found: %s", pathToFile)
			return nil, err1
		}
		return getSpec()
	}
	var specData []byte
	specData, err = rawSpec()
	if err != nil {
		return
	}
	swagger, err = loader.LoadFromData(specData)
	if err != nil {
		return
	}
	return
}
