// -
//   ========================LICENSE_START=================================
//   O-RAN-SC
//   %%
//   Copyright (C) 2022: Nordix Foundation
//   %%
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//        http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.
//   ========================LICENSE_END===================================
//

package security

import (
	"fmt"
	"net/http"
	"net/url"
	"os"
	"testing"

	"github.com/deepmap/oapi-codegen/pkg/middleware"
	"github.com/deepmap/oapi-codegen/pkg/testutil"
	"github.com/labstack/echo/v4"
	echomiddleware "github.com/labstack/echo/v4/middleware"
	"github.com/stretchr/testify/assert"
	"oransc.org/nonrtric/plt/capif/internal/invokermanagement"
	invokermocks "oransc.org/nonrtric/plt/capif/internal/invokermanagement/mocks"
	"oransc.org/nonrtric/plt/capif/internal/providermanagement"
	servicemocks "oransc.org/nonrtric/plt/capif/internal/providermanagement/mocks"
	"oransc.org/nonrtric/plt/capif/internal/publishservice"
	publishmocks "oransc.org/nonrtric/plt/capif/internal/publishservice/mocks"
	"oransc.org/nonrtric/plt/capif/internal/readonly/securityapi"
)

func TestPostSecurityIdToken(t *testing.T) {
	invokerRegisterMock := invokermocks.InvokerRegister{}
	serviceRegisterMock := servicemocks.ServiceRegister{}
	apiRegisterMock := publishmocks.APIRegister{}

	requestHandler := getEcho(&serviceRegisterMock, &apiRegisterMock, &invokerRegisterMock)

	data := url.Values{}
	data.Set("client-id", "id")
	data.Add("client-secret", "secret")
	data.Add("grant-type", "type")
	data.Add("scope", "scope")
	encodedData := data.Encode()

	result := testutil.NewRequest().Post("/securities/invokerId/token").WithContentType("application/x-www-form-urlencoded").WithBody([]byte(encodedData)).Go(t, requestHandler)

	assert.Equal(t, http.StatusOK, result.Code())

}

func getEcho(serviceRegister providermanagement.ServiceRegister, apiRegister publishservice.APIRegister, invokerRegister invokermanagement.InvokerRegister) *echo.Echo {
	swagger, err := securityapi.GetSwagger()
	if err != nil {
		fmt.Fprintf(os.Stderr, "Error loading swagger spec\n: %s", err)
		os.Exit(1)
	}

	swagger.Servers = nil

	s := NewSecurity(serviceRegister, apiRegister, invokerRegister)

	e := echo.New()
	e.Use(echomiddleware.Logger())
	e.Use(middleware.OapiRequestValidator(swagger))

	securityapi.RegisterHandlers(e, s)
	return e
}
